@@ -348,7 +348,7 @@ class FieldAccessEntry {
    */
   virtual void Set(void *head, const std::string &value) const = 0;
   // check if value is OK
-  virtual void Check(void *head) const {}
+  virtual void Check(void * /*head*/) const {}
   /*!
    * \brief get the string representation of value.
    * \param head the pointer to the head of the struct
@@ -776,7 +776,7 @@ class FieldEntry<int>
     : public FieldEntryNumeric<FieldEntry<int>, int> {
  public:
   // construct
-  FieldEntry<int>() : is_enum_(false) {}
+  FieldEntry() : is_enum_(false) {}
   // parent
   typedef FieldEntryNumeric<FieldEntry<int>, int> Parent;
   // override set
@@ -882,7 +882,7 @@ class FieldEntry<optional<int> >
     : public FieldEntryBase<FieldEntry<optional<int> >, optional<int> > {
  public:
   // construct
-  FieldEntry<optional<int> >() : is_enum_(false) {}
+  FieldEntry() : is_enum_(false) {}
   // parent
   typedef FieldEntryBase<FieldEntry<optional<int> >, optional<int> > Parent;
   // override set
