@@ -59,8 +59,6 @@ struct Monitor {
   std::map<std::string, Statistics> statistics_map_;
   Timer self_timer_;
 
-  /*! \brief Collect time statistics across all workers. */
-  std::vector<StatMap> CollectFromOtherRanks() const;
   void PrintStatistics(StatMap const& statistics) const;
 
  public:
@@ -82,8 +80,6 @@ struct Monitor {
   void Init(std::string label) { this->label_ = label; }
   void Start(const std::string &name);
   void Stop(const std::string &name);
-  void StartCuda(const std::string &name);
-  void StopCuda(const std::string &name);
 };
 }  // namespace common
 }  // namespace xgboost
